@@ -1,6 +1,14 @@
-#' @method predict MxModel
+#' @title Predict Class Membership
+#' @description Predict class membership for latent class analyses conducted
+#' with `tidySEM` in `OpenMx`.
+#' @param object An `MxModel` object with attribute `tidySEM = "mixture"`.
+#' @param newdata A `data.frame` with the same column names and data types as
+#' the one used to estimate the model.
+#' @param ... Other arguments passed to `predict.MxModel()`.
+#' @return A `data.frame`.
+#' @rdname predict_class
 #' @export
-predict.MxModel <- function(object,
+predict_class <- function(object,
                             newdata,
                             ...){
   cl <- match.call()
