@@ -13,7 +13,9 @@ table_results.mixture_list <- function (x, columns = c("label", "est_sig", "se",
     }
     tmp
   }))
-  bind_list(out)
+  out <- bind_list(out)
+  rownames(out) <- NULL
+  out
 }
 #' @method table_results MxModel
 #' @export
@@ -22,6 +24,9 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
 {
   # Multigroup:
   # attr(attr(fit,"runstate")$fitfunctions$mg.fitfunction, "groups")
+  if(!x@.wasRun) {
+    stop("This model has not been run yet. Use `model = tidySEM::run_mx(model)` or `model = OpenMx::mxRun(model)` to estimate a model.")
+  }
   Args <- list(x = x)
   digits <- force(digits)
   sum_x <- summary(x)
@@ -127,7 +132,7 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
   lav_labs <- mx_to_lavaan_labels(results)
   results <- cbind(results, lav_labs)
   # Drop internal stuff
-  internalstuff <- grepl("mat_dev", results$name)
+  internalstuff <- grepl("(mat_dev|mat_ones)", results$name)
   if(any(internalstuff)) results <- results[!internalstuff, ]
   # Make uniform column names
   renam <- c(std.value = "est_std", std.se = "se_std")
@@ -157,6 +162,7 @@ table_results.MxModel <- function (x, columns = c("label", "est_sig", "se", "pva
                                                              names(results)))
     results <- results[, order_cols, drop = FALSE]
   }
+
   rownames(results) <- NULL
   class(results) <- c("tidy_results", class(results))
   return(results)
@@ -349,6 +355,15 @@ flat <- function(x){
                            Estimate = val,
                            formula = deparse(x[[thisalg]]$formula),
                            row.names = NULL)
+      # Drop unused thresholds
+      if(thisalg == "Thresholds"){
+        if(!is.null(x[["Indicators"]])){
+          # Drop thresholds for deviances that don't have a label, as these should be bogus
+          if(isTRUE(any(x[["Indicators"]]$values == 0))){
+            addalg <- addalg[-which(x[["Indicators"]]$values == 0), , drop = FALSE]
+          }
+        }
+      }
       addthis <- c(addthis, list(addalg))
     }
     names(addthis) <- algs
