@@ -25,6 +25,12 @@ paste2 <- function(..., sep = " ", collapse = NULL, na.rm = TRUE){
     paste(na.omit(res), collapse = collapse)
 }
 
+diag_bind <- function(a, b, pad = NA){
+  top <- cbind(a, matrix(data = pad, nrow = nrow(a), ncol = ncol(b)))
+  bottom <- cbind(matrix(data = pad, nrow = nrow(b), ncol = ncol(a)), b)
+  colnames(top)[-c(1:ncol(a))] <- colnames(b)
+  rbind(top, bottom)
+}
 
 # @title Longest common substring
 # @description Extract the longest common substring of two strings using
