@@ -139,6 +139,7 @@ if(requireNamespace("OpenMx", quietly = TRUE)){
   #df <- data_mix_ordinal
   #df[1:4] <- lapply(df, function(i){ordered(as.integer(i==0))})
   set.seed(1)
+
   # Just thresholds
   res_mx <- run_mx(as_ram(
     "u1 | t1*t1
@@ -184,10 +185,10 @@ u4 | t4{C}*t1", classes = 2, data = df, run = FALSE)
   #             modelout = "test.inp",
   #             run = 1L
   #             )
-  res_mx$class1$Thresholds$values <- structure(c(-1.21202423291062, -1.03055648196733, 1.34960931996936,
-                                                 1.21984168386381), .Dim = c(1L, 4L))
-  res_mx$class2$Thresholds$values <- structure(c(1.22655751606709, 1.20822650045262, -1.2762983140788,
-                                                 -1.14581064840368), .Dim = c(1L, 4L))
+  # res_mx$class1$Thresholds$values <- structure(c(-1.21202423291062, -1.03055648196733, 1.34960931996936,
+  #                                                1.21984168386381), .Dim = c(1L, 4L))
+  # res_mx$class2$Thresholds$values <- structure(c(1.22655751606709, 1.20822650045262, -1.2762983140788,
+  #                                                -1.14581064840368), .Dim = c(1L, 4L))
 
   res_mx <- mxTryHardOrdinal(res_mx)
   tmp <- table_results(res_mx, columns=NULL)
